﻿using Infragistics.Controls.Editors;
using Infragistics.Documents.RichText;
using Infragistics.Windows.Ribbon;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {

        private List<ToggleButtonTool> _bulletListItems = new List<ToggleButtonTool>();
        private List<ToggleButtonTool> _numberListItems = new List<ToggleButtonTool>();

        public MainWindow()
        {
            InitializeComponent();
            InitializeControls();
        }

        private void InitializeControls()
        {
            RichTextEditor.SelectionChanged += RichTextEditor_SelectionChanged;
        }

        void RichTextEditor_SelectionChanged(object sender, Infragistics.Controls.Editors.SelectionChangedEventArgs e)
        {
            CharacterSettings cs = RichTextEditor.Document.GetCommonCharacterSettings(RichTextEditor.Selection.DocumentSpan, true);
            bold.IsChecked = cs.Bold == true;
            underline.IsChecked = cs.UnderlineType == UnderlineType.Single;
            italic.IsChecked = cs.Italics == true;
            color.IsChecked = (cs.Color == null ? false : (cs.Color.Color == Colors.Red));
        }

        public XamRichTextEditor RichTextEditor
        {
            get { return this.xamRichTextEditor1; }
        }

        public List<ToggleButtonTool> NumberListItems
        {
            get
            {
                return _numberListItems;
            }
        }

        public List<ToggleButtonTool> BulletListItems
        {
            get
            {
                return _bulletListItems;
            }
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            ToggleButton b = sender as ToggleButton;
            Selection selection = RichTextEditor.Selection;
            if (b.Name.Equals("bold"))
            {
                if (b.IsChecked == true)
                {
                    selection.ApplyBoldFormatting();
                }
                else
                {
                    selection.RemoveBoldFormatting();
                }
            }
            else if (b.Name.Equals("italic"))
            {
                if (b.IsChecked == true)
                {
                    selection.ApplyItalicFormatting();
                }
                else
                {
                    selection.RemoveItalicFormatting();
                }
            }
            else if (b.Name.Equals("underline"))
            {
                if (b.IsChecked == true)
                {
                    selection.ApplyFontUnderlineFormatting(UnderlineType.Single);
                }
                else
                {
                    selection.ApplyFontUnderlineFormatting(UnderlineType.None);
                }
            }
            else if (b.Name.Equals("color"))
            {
                if (b.IsChecked == true)
                {
                    selection.ApplyTextForecolor(new ColorInfo(Colors.Red));
                }
                else
                {
                    selection.ApplyTextForecolor(new ColorInfo(Colors.Black));
                }
            }
            RichTextEditor.Focus();
        }
    }
}
